fileio Package
==============

:mod:`fileio` Package
---------------------

.. automodule:: masai.fileio
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`source` Module
--------------------

.. automodule:: masai.fileio.source
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    masai.fileio.nmrglue

